@@ -291,8 +291,14 @@ double AT_RDD_d_max_Gy(
 
   double d_max_Gy  = 0.0;
 
+  double LET_MeV_cm2_g;
+  AT_Mass_Stopping_Power_with_no( stopping_power_source_no,
+		  1,
+		  &E_MeV_u,
+		  &particle_no,
+		  material_no,
+		  &LET_MeV_cm2_g);
   const double max_electron_range_m      =  AT_max_electron_range_m( E_MeV_u, (int)material_no, (int)er_model);
-  const double LET_MeV_cm2_g             =  AT_Stopping_Power_MeV_cm2_g_single( stopping_power_source_no, E_MeV_u, particle_no, material_no);
   const double precalculated_constant_Gy =  AT_RDD_precalculated_constant_Gy(max_electron_range_m, LET_MeV_cm2_g, E_MeV_u, particle_no, material_no, rdd_model, rdd_parameter, er_model);
 
   // Get density // TODO move it down
@@ -399,7 +405,12 @@ void AT_RDD_f1_parameters_single_field(
 
   ///////////////////////////////////////////////////////////////////////////////
   // PARAMETER 0: Get the LET
-  LET_MeV_cm2_g = AT_Stopping_Power_MeV_cm2_g_single( stopping_power_source_no, E_MeV_u, particle_no, material_no);
+  AT_Mass_Stopping_Power_with_no( stopping_power_source_no,
+  			  1,
+  			  &E_MeV_u,
+  			  &particle_no,
+  			  material_no,
+  			  &LET_MeV_cm2_g);
 
   //////////////////////////////////////////////////////////////////////////////////////
   // PARAMETER 2: Get the maximum electron range (same for all RDD models but tabulated)
@@ -499,7 +510,13 @@ int AT_D_RDD_Gy( const long  n,
    ********* CALCULATION BEFORE PARTICLE LOOP *************
    *******************************************************/
 
-  const double LET_MeV_cm2_g          =  AT_Stopping_Power_MeV_cm2_g_single( stopping_power_source_no, E_MeV_u, particle_no, material_no);
+  double LET_MeV_cm2_g;
+  AT_Mass_Stopping_Power_with_no( stopping_power_source_no,
+  			  1,
+  			  &E_MeV_u,
+  			  &particle_no,
+  			  material_no,
+  			  &LET_MeV_cm2_g);
 
   const double max_electron_range_m   =  AT_max_electron_range_m( E_MeV_u, (int)material_no, (int)er_model);
 
@@ -666,7 +683,13 @@ int AT_r_RDD_m  ( const long  n,
  	return 0;
    }// end RDD_RadicalDiffusion
 
-  const double LET_MeV_cm2_g              =  AT_Stopping_Power_MeV_cm2_g_single( stopping_power_source_no, E_MeV_u, particle_no, material_no);
+  double LET_MeV_cm2_g;
+  	  AT_Mass_Stopping_Power_with_no( stopping_power_source_no,
+  			  1,
+  			  &E_MeV_u,
+  			  &particle_no,
+  			  material_no,
+  			  &LET_MeV_cm2_g);
 
   const double max_electron_range_m       =  AT_max_electron_range_m(E_MeV_u, (int)material_no, (int)er_model);
 
